#
# spec file for package limine
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2025 Marvin Friedrich
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.
#

Name:           limine
Version:        9.4.0
Release:        1.1
Summary:        Modern, advanced, portable, multiprotocol bootloader and boot manager
License:        BSD-2-Clause
Group:          System/Boot
URL:            https://github.com/limine-bootloader/limine
Source:         %{url}/releases/download/v%{version}/%{name}-%{version}.tar.gz
BuildRequires:  make
BuildRequires:  autoconf
BuildRequires:  nasm
BuildRequires:  mtools
BuildRequires:  clang
BuildRequires:  lld
BuildRequires:  llvm
ExclusiveArch:  x86_64 riscv64 aarch64 loongarch64

%description
Limine is a modern, advanced, portable, multiprotocol bootloader and boot manager,
also used as the reference implementation for the Limine boot protocol.

%prep
%setup -q

%build
%configure --enable-all --docdir=%{_docdir}/%{name} TOOLCHAIN_FOR_TARGET=llvm
%make_build

%install
%make_install

%files
%{_bindir}/limine
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/BOOTAA64.EFI
%{_datadir}/%{name}/BOOTIA32.EFI
%{_datadir}/%{name}/BOOTLOONGARCH64.EFI
%{_datadir}/%{name}/BOOTRISCV64.EFI
%{_datadir}/%{name}/BOOTX64.EFI
%{_datadir}/%{name}/limine-bios-cd.bin
%{_datadir}/%{name}/limine-bios-pxe.bin
%{_datadir}/%{name}/limine-bios.sys
%{_datadir}/%{name}/limine-uefi-cd.bin
%{_mandir}/man1/limine.1.gz
%doc %{_docdir}/%{name}

# Development package
%package -n limine-devel
Summary:        Development files for Limine
BuildArch:      noarch

%description -n limine-devel
C header with Limine structures.

%files -n limine-devel
%{_includedir}/limine.h

%changelog
* Thu Jul 10 2025 Marvin Friedrich <contact@marvinf.com>
- Update to 9.4.0:
  * BLI: Implement `LoaderTimeInitUSec` and `LoaderTimeExecUSec`.
    These are variables used by `systemd-analyze` and are useful for boot
    performance metrics.
  * Limine boot protocol: Add bootloader performance feature.
    This feature provides the same information as the new Boot Loader
    Interface variables, but encoded in a nicer way for Limine protocol
    executables.
* Sat Jun 21 2025 Marvin Friedrich <contact@marvinf.com>
- Update to 9.3.4:
  * ELF: Make an optimisation related to skipping scanning of .bss
    regions for finding of structures in the loaded image (for Limine
    protocol structures or otherwise) less overeager as that could break
    in certain cases.
  * SMP: On x86, ensure that the value of IA32_APIC_BASE is the same on
    the APs as it is on the BSP.
  * PMM: Mark EfiLoader{Code,Data} regions as bootloader reclaimable
    rather than reserved memory, as for certain protocols, like the
    Limine boot protocol, reserved memory is unmapped at runtime, while
    these regions may contain hot data that is still needed, like Limine
    bootloader memory stacks.
* Tue May 27 2025 Marvin Friedrich <contact@marvinf.com>
- Update to 9.3.3:
  * Reinstate the limit for scanned drives to 0xf0. This is due to a
    report of int 13h hangs when used on drives >=0xf0
* Fri May 23 2025 Marvin Friedrich <contact@marvinf.com>
- Update to 9.3.2:
  * Mark EfiBootServices{Code,Data} memory regions as bootloader
    reclaimable instead of usable free memory
* Wed May  7 2025 Marvin Friedrich <contact@marvinf.com>
- Update to 9.3.0:
  * Add optional support for the 64-bit x86-64 boot protocol for Linux.
  * Fix away some ungraceful handling of out-of-memory situations when
    loading files using the Linux boot protocol.
  * Improve performance and memory usage of loading modules for the
    Linux boot protocol.
* Sat Apr 19 2025 Marvin Friedrich <contact@marvinf.com>
- Update to 9.2.3:
  * Fix issues introduced by the stb_image fix introduced in 9.2.1 which
    could cause hangs or crashes when certain wallpaper images are used.
* Mon Mar 31 2025 Marvin Friedrich <contact@marvinf.com>
- Update to 9.2.2:
  * Fixes and workarounds in order to make multiboot2 more
    resilient when booting specific kernels such as Xen.
  * Avoid mistakenly allocating more memory than necessary when
    creating the volume index.
* Tue Mar 25 2025 Marvin Friedrich <contact@marvinf.com>
- Update to 9.2.1:
  * Fix potential buffer overflow bug with stb_image support code.
  * Print the name of unresolved symbols on panic.
  * Dynamically allocate volume index instead of relying on a hard coded
    limit and a fixed allocation.
* Thu Mar 20 2025 Marvin Friedrich <contact@marvinf.com>
- Correct docdir install location
* Thu Mar 20 2025 Marvin Friedrich <contact@marvinf.com>
- Use %%configure macro to build
* Wed Mar 19 2025 Marvin Friedrich <contact@marvinf.com>
- Update to 9.2.0
* Fri Mar 14 2025 Marvin Friedrich <contact@marvinf.com>
- Use LLVM toolchain to build all targets
* Fri Mar 14 2025 Marvin Friedrich <contact@marvinf.com>
- Update to 9.1.3
- Remove unused macro
* Mon Feb 17 2025 Marvin Friedrich <contact@marvinf.com>
- Update to 9.0.0
* Sat Dec  7 2024 Marvin Friedrich <contact@marvinf.com>
- Update to 8.6.0
* Mon Nov 18 2024 Marvin Friedrich <contact@marvinf.com>
- Update to 8.4.0
* Tue Jul  2 2024 Marvin Friedrich <contact@marvinf.com>
- Fix EFI_SUFFIX variable
* Tue Jul  2 2024 Marvin Friedrich <contact@marvinf.com>
- EFI bootentry creation
* Tue Jul  2 2024 Marvin Friedrich <contact@marvinf.com>
- Make UEFI binary part of seperate package
* Tue Jul  2 2024 Marvin Friedrich <contact@marvinf.com>
- Remove config, leave that part to the user
* Tue Jul  2 2024 Marvin Friedrich <contact@marvinf.com>
- Modify boot config
* Tue Jul  2 2024 Marvin Friedrich <contact@marvinf.com>
- Add default boot config
* Tue Jul  2 2024 Marvin Friedrich <contact@marvinf.com>
- Fixed RISC-V EFI filename
* Tue Jul  2 2024 Marvin Friedrich <contact@marvinf.com>
- Added EFI building
* Tue Jul  2 2024 Marvin Friedrich <contact@marvinf.com>
- Initial update to v7.9.1
